#
# spec file for package python-csvkit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define binaries csvclean csvcut csvformat csvgrep csvjoin csvjson csvlook csvpy csvsort csvsql csvstack csvstat in2csv sql2csv
Name:           python-csvkit
Version:        2.0.1
Release:        1.2
Summary:        A library of utilities for working with CSV
License:        MIT
URL:            https://github.com/wireservice/csvkit
Source0:        https://files.pythonhosted.org/packages/source/c/csvkit/csvkit-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/wireservice/csvkit/5f22e664121b13d9ff005a9206873a8f97431dca/examples/testdbf_converted.csv
BuildRequires:  %{python_module agate >= 1.6.3}
BuildRequires:  %{python_module agate-dbf >= 0.2.0}
BuildRequires:  %{python_module agate-excel >= 0.2.2}
BuildRequires:  %{python_module agate-sql >= 0.5.3}
BuildRequires:  %{python_module importlib-metadata if %python-base < 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-SQLAlchemy
Requires:       python-agate >=  1.6.3
Requires:       python-agate-dbf >= 0.2.0
Requires:       python-agate-excel
Requires:       python-agate-sql
Requires:       python-openpyxl
Requires:       python-xlrd
Recommends:     python-zstandard
%if %python_version_nodots < 310
Requires:       python-importlib-metadata
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
CSVkit is a library of utilities for working with CSV. It is inspired
by pdftk, gdal and the original csvcut utility by Joe Germuska and
Aaron Bycoffe.

%prep
%setup -q -n csvkit-%{version}
# find and remove unneeded shebangs
find csvkit -name "*.py" | xargs sed -i '1 {/^#!/ d}'
# agate-dbf >= 0.2.2 creates uppercase fieldnames for this example file -- gh#wireservice/csvkit#1073
%if %{pkg_vcmp python3-agate-dbf >= 0.2.2}
cp %{SOURCE1} examples/testdbf_converted.csv
%endif

%build
%pyproject_wheel

%install
%pyproject_install
for b in %{binaries}; do
  %python_clone -a %{buildroot}%{_bindir}/$b
  %python_clone -a %{buildroot}%{_mandir}/man1/${b}.1
done
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pyunittest discover -s tests/ -v

%post
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_install_alternative " .. b .. "\n"))
  print(rpm.expand("%python_install_alternative " .. b .. ".1%{ext_man}\n"))
end}

%postun
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_uninstall_alternative " .. b .. "\n"))
  print(rpm.expand("%python_uninstall_alternative " .. b .. ".1%{ext_man}\n"))
end}

%files %{python_files}
%license COPYING
%doc AUTHORS.rst CHANGELOG.rst README.rst
%{lua:for b in rpm.expand("%{binaries}"):gmatch("%S+") do
  print(rpm.expand("%python_alternative %{_bindir}/" .. b .. "\n"))
  print(rpm.expand("%python_alternative %{_mandir}/man1/" .. b .. ".1%{ext_man}" .. "\n"))
end}
%{python_sitelib}/csvkit
%{python_sitelib}/csvkit-%{version}.dist-info

%changelog
* Tue Jul 23 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.1:
  * feat: csvsql adds --min-col-len and --col-len-multiplier options.
  * feat: sql2csv adds a --engine-option option.
  * feat: Add man pages to the sdist and wheel distributions.
  * fix: csvstat no longer errors when a column is a time delta and --json
    is set.
  * csvclean now writes its output to standard output and its errors to
    standard error, instead of to basename_out.csv and basename_err.csv
    files.
  * csvclean no longer reports or fixes errors by default; it errors if no
    checks or fixes are enabled.
  * csvclean no longer omits rows with errors from the output.
  * csvclean joins short rows using a newline by default, instead of a space.
  * Add a lot of options to csvclean.
  * feat: The --quoting option accepts csv.QUOTE_STRINGS and
    csv.QUOTE_NOTNULL on Python 3.12.
  * feat: csvformat: The --out-quoting option accepts csv.QUOTE_STRINGS
    and csv.QUOTE_NOTNULL on Python 3.12.
  * fix: csvformat: The --out-quoting option works with csv.QUOTE_NONUMERIC.
  * fix: csvclean: The --join-short-rows option no longer reports length
    mismatch errors that were fixed.
  * feat: Add support for Zstandard files with the .zst extension, if the
    zstandard package is installed.
  * feat: csvformat adds a --out-asv (--A) option to use the ASCII unit
    separator and record separator.
  * feat: csvsort adds a --ignore-case (--i) option to perform
    case-independent sorting.
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * feat: :doc:`/scripts/csvpy` adds the options:   --no-number-
    ellipsis, to disable the ellipsis (…) if max precision is
    exceeded, for example, when using table.print_table()
  - -sniff-limit` --no-inference`
  * feat: :doc:`/scripts/csvpy` adds the options:
  * --no-number-ellipsis, to disable the ellipsis (…) if max
    precision is exceeded, for example, when using
    table.print_table()
  * feat: :doc:`/scripts/csvpy` removes the --linenumbers and
  - -zero output options, which had no effect.
  * feat: :doc:`/scripts/csvpy` removes the --linenumbers and
  - -zero output options, which had no effect.
  * feat: :doc:`/scripts/in2csv` adds a --reset-dimensions option
    to recalculate the dimensions of an XLSX file, instead of
    trusting the file's metadata. csvkit's dependency agate-excel
    0.4.0 automatically recalculates the dimensions if the file's
    metadata expresses dimensions of "A1:A1" (a single cell).
  * feat: :doc:`/scripts/in2csv` adds a --reset-dimensions option
    to recalculate the dimensions of an XLSX file, instead of
    trusting the file's metadata. csvkit's dependency agate-excel
    0.4.0 automatically recalculates the dimensions if the file's
    metadata expresses dimensions of "A1:A1" (a single cell).
  * fix: :doc:`/scripts/csvlook` only reads up to --max-rows rows
    instead of the entire file.
  * fix: :doc:`/scripts/csvlook` only reads up to --max-rows rows
    instead of the entire file.
  * fix: :doc:`/scripts/csvpy` supports the existing input
    options:   --locale --blanks --null-value --date-format
  - -datetime-format --skip-lines
  * Update minimum agate version to 1.6.3.
* Thu Dec 14 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3.0:
  * /scripts/csvformat adds a --skip-header (-E) option to not output a
    header row.
  * /scripts/csvlook adds a --max-precision option to set the maximum number
    of decimal places to display.
  * /scripts/csvlook adds a --no-number-ellipsis option to disable the
    ellipsis (…) if --max-precision is exceeded.
  * /scripts/csvstat supports the --no-inference (-I), --locale (-L),
  - -blanks, --date-format and datetime-format options.
  * /scripts/csvstat reports a "Non-null values" statistic.
  * /scripts/csvstat adds a --non-nulls option to only output counts
    of non-null values.
  * /scripts/csvstat reports a "Most decimal places" statistic.
  * /scripts/csvstat adds a --max-precision option to only output the
    most decimal places.
  * /scripts/csvstat adds a --json option to output results as JSON text.
  * /scripts/csvstat adds an --indent option to indent the JSON text when
  - -json is set.
  * /scripts/in2csv adds a --use-sheet-names option to use the sheet names
    as file names when --write-sheets is set.
  * Add a --null-value option to commands with the --blanks option, to
    convert additional values to NULL.
  * Reconfigure the encoding of standard input according to the --encoding
    option, which defaults to utf-8-sig.
  * Prompt the user if additional input is expected (i.e. if no input file
    or piped data is provided) in /scripts/csvjoin, /scripts/csvsql and
    /scripts/csvstack.
  * No longer errors if a NUL byte occurs in an input file.
  * Add Python 3.12 support.
  * /scripts/csvjoin uses the correct columns when performing a --right join.
  * Add SQLAlchemy 2 support.
  * Drop Python 3.7 support (end-of-life was June 5, 2023).
- Switch to pyproject macros.
* Fri Sep 29 2023 Ondřej Súkup <mimi.vx@gmail.com>
-  cleanup package requires and buildrequires
* Tue May 30 2023 Dirk Müller <dmueller@suse.com>
- require sqlalchemy < 2 due to agate-sql
* Mon Apr 17 2023 pgajdos@suse.com
- python-six is not required
- Add missing Requires.
* Tue Mar 28 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.1:
  * feat: :doc:`/scripts/csvstack` handles files with columns in
    different orders or with different names.
* Mon Jan 16 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * feat: :doc:`/scripts/csvsql` accepts multiple :code:`--query` command-
    line arguments.
  * feat: :doc:`/scripts/csvstat` adds :code:`--no-grouping-separator` and
    :code:`--decimal-format` options.
  * Add Python 3.11 support.
  * Drop Python 3.6 support (end-of-life was December 23, 2021).
  * Drop Python 2.7 support (end-of-life was January 1, 2020).
* Fri Oct  7 2022 Daniel Garcia <daniel.garcia@suse.com>
- Fix u-a scriptlets
- Update to v1.0.7
  * fix: :doc:`/scripts/csvcut` extracts the correct columns when
  - -line-numbers is set.
  * fix: Restore Python 2.7 support in edge cases.
  * feat: Use 1024 byte sniff-limit by default across csvkit. Improve csvstat
    performance up to 10x.
  * feat: Add support for .xz (LZMA) compressed input files.
  * Add Python 3.10 support.
  * Drop Python 3.5 support (end-of-life was September 30, 2020).
- v1.0.6
  * :doc:`/scripts/csvstat` no longer prints "Row count: " when --count is set.
  * :doc:`/scripts/csvclean`, :doc:`/scripts/csvcut`, :doc:`/scripts/csvgrep`
    no longer error if standard input is null.
  * :doc:`/scripts/csvformat` creates default headers when --no-header-row is
    set, as documented.
  * :doc:`/scripts/csvstack` no longer errors when --no-header-row is combined
    with --groups or --filenames.
* Sun Feb 28 2021 Ben Greiner <code@bnavigator.de>
- Add testdbf_converted.csv to fix a test failure since
  agate-dbf 0.2.2 -- gh#wireservice/csvkit#1073
- Make rpmlint happy by expanding the u-a install scripts early.
  (Keep all the cli commands as their own u-a master links.)
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop py2 deps as it works only on py3 atm
* Thu Mar 26 2020 Paolo Stivanin <info@paolostivanin.com>
- update to v1.0.5
  * dropped py 3.4 support
  * fix tests
  * minor fixes
- switch from nose to unittest
* Mon Dec  2 2019 Todd R <toddrme2178@gmail.com>
- Drop python2 support due to dependencies dropping python2 support
* Wed Apr 24 2019 Matej Cepl <mcepl@suse.com>
- boo#1133137: Fix FTBFS python-csvkit (failing tests gh#wireservice/csvkit#1027)
* Mon Mar 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.4:
  * Dropped Python 3.3 support (end-of-life was September 29, 2017).
  * :doc:`/scripts/csvsql` adds a --chunk-size option to set the chunk size when batch inserting into a table.
  * csvkit is now tested against Python 3.7.
  * Dates and datetimes without punctuation can be parsed with --date-format and datetime-format.
  * Error messages about column indices use 1-based numbering unless --zero is set.
- Remove merged patch remove-unittest2.patch
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove devel dependency and do not use symlinks on fdupes call
* Sun Aug 12 2018 mcepl@suse.com
- We already use six, so it is better to use monkey-patching already
  prepared there. remove-unittest2.patch updated.
  Upstream pull request https://github.com/wireservice/csvkit/pull/979
* Fri Aug 10 2018 mcepl@suse.com
- Remove unnecessary unittest2 dependency
  (Patch remove-unittest2.patch makes necessary changes)
* Sun Jul 29 2018 jengelh@inai.de
- Remove bias from descriptions.
* Mon Jun  4 2018 toddrme2178@gmail.com
- Remove unneded dependencies
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 1.0.3
  + Improvements:
  * :doc:`/scripts/csvgrep` adds a :code:`--any-match` (:code:`-a`) flag to select rows where any column matches instead of all columns.
  * :doc:`/scripts/csvjson` no longer emits a property if its value is null.
  * :doc:`/scripts/csvjson` adds :code:`--type` and :code:`--geometry` options to emit non-Point GeoJSON features.
  * :doc:`/scripts/csvjson` adds a :code:`--no-bbox` option to disable the calculation of a bounding box.
  * :doc:`/scripts/csvjson` supports :code:`--stream` for newline-delimited GeoJSON.
  * :doc:`/scripts/csvsql` adds a :code:`--unique-constraint` option to list names of columns to include in a UNIQUE constraint.
  * :doc:`/scripts/csvsql` adds :code:`--before-insert` and :code:`--after-insert` options to run commands before and after the INSERT command.
  * :doc:`/scripts/csvpy` reports an error message if input is provided via STDIN.
  * :doc:`/scripts/in2csv` adds a :code:`--encoding-xls` option to specify the encoding of the input XLS file.
  * :doc:`/scripts/in2csv` supports :code:`--no-header-row` on XLS and XLSX files.
  * Suppress agate warning about column names not specified when using :code:`--no-header-row`.
  * Prompt the user if additional input is expected (i.e. if no input file or piped data is provided).
  * Update to `agate-excel 0.2.2 <http://agate-excel.readthedocs.io/en/0.2.2/#changelog>`_, `agate-sql 0.5.3 <http://agate-sql.readthedocs.io/en/0.5.3/#changelog>`_.
  + Fixes:
  * :doc:`/scripts/csvgrep` accepts utf-8 arguments to the :code:`--match` and :code:`--regex` options in Python 2.
  * :doc:`/scripts/csvjson` streams input and output only if :code:`--snifflimit` is :code:`0`.
  * :doc:`/scripts/csvsql` sets a DECIMAL's precision and scale and a VARCHAR's length to avoid dialect-specific errors.
  * :doc:`/scripts/csvstack` no longer opens all files at once.
  * :doc:`/scripts/in2csv` respects :code:`--no-header-row` when :code:`--no-inference` is set.
  * :doc:`/scripts/in2csv` CSV-to-CSV conversion streams input and output only if :code:`--snifflimit` is :code:`0`.
  * :doc:`/scripts/in2csv` supports GeoJSON files with: ``geometry`` set to ``null``, missing Point ``coordinates``, altitude coordinate values.
  + csvkit is no longer tested on PyPy.
- Update to 1.0.2
  + Improvements:
  * Add a :code:`--version` flag.
  * Add a :code:`--skip-lines` option to skip initial lines (e.g. comments, copyright notices, empty rows).
  * Add a :code:`--locale` option to set the locale of any formatted numbers.
  * Add a :code:`--date-format` option to set a strptime date format string.
  * Add a :code:`--datetime-format` option to set a strptime datetime format string.
  * Make :code:`--blanks` a common argument across all tools.
  * :code:`-I` is the short option for :code:`--no-inference`.
  * :doc:`/scripts/csvclean`, :doc:`/scripts/csvformat`, :doc:`/scripts/csvjson`, :doc:`/scripts/csvpy` support :code:`--no-header-row`.
  * :doc:`/scripts/csvclean` is faster and no longer requires exponential time in the worst case.
  * :doc:`/scripts/csvformat` supports :code:`--linenumbers` and `--zero` (no-op).
  * :doc:`/scripts/csvjoin` supports :code:`--snifflimit` and :code:`--no-inference`.
  * :doc:`/scripts/csvpy` supports :code:`--linenumbers` (no-op) and :code:`--zero` (no-op).
  * :doc:`/scripts/csvsql` adds a :code:`--prefix` option to add expressions like OR IGNORE or OR REPLACE following the INSERT keyword.
  * :doc:`/scripts/csvsql` adds a :code:`--overwrite` flag to drop any existing table with the same name before creating.
  * :doc:`/scripts/csvsql` accepts a file name for the :code:`--query` option.
  * :doc:`/scripts/csvsql` supports :code:`--linenumbers` (no-op).
  * :doc:`/scripts/csvsql` adds a :code:`--create-if-not-exists` flag to not abort if the table already exists.
  * :doc:`/scripts/csvstat` adds a :code:`--freq-count` option to set the maximum number of frequent values to display.
  * :doc:`/scripts/csvstat` supports :code:`--linenumbers` (no-op).
  * :doc:`/scripts/in2csv` adds a :code:`--names` flag to print Excel sheet names.
  * :doc:`/scripts/in2csv` adds a :code:`--write-sheets` option to write the named Excel sheets to files.
  * :doc:`/scripts/sql2csv` adds an :code:`--encoding` option to specify the encoding of the input query file.
  + Fixes:
  * :doc:`/scripts/csvgrep` no longer ignores common arguments if :code:`--linenumbers` is set.
  * :doc:`/scripts/csvjson` supports Decimal.
  * :doc:`/scripts/csvpy` again supports IPython.
  * :doc:`/scripts/csvsql` restores support for :code:`--no-constraints` and :code:`--db-schema`.
  * :doc:`/scripts/csvstat` will no longer crash when :code:`--freq` is set.
  * :doc:`/scripts/in2csv` restores support for :code:`--no-inference` for Excel files.
  * :doc:`/scripts/in2csv` restores support for converting Excel files from standard input.
  * :doc:`/scripts/in2csv` accepts utf-8 arguments to the :code:`--sheet` option in Python 2.
- Update to 1.0.1
  * :doc:`/scripts/csvstat` will no longer crash when a :code:`Number` column has :code:`None` as a frequent value. (#738)
  * :doc:`/scripts/csvlook` docs now note that output tables are Markdown-compatible. (#734)
  * :doc:`/scripts/csvstat` now supports a :code:`--csv` flag for tabular output. (#584)
  * :doc:`/scripts/csvstat` output is now easier to read. (#714)
  * :doc:`/scripts/csvpy` now has a better description when using the :code:`--agate` flag. (#729)
  * Fix a Python 2.6 bug preventing :doc:`/scripts/csvjson` from parsing utf-8 files. (#732)
  * Update required version of unittest to latest. (#727)
- Update to 1.0.0
  + Backwards-incompatible changes:
  * :doc:`/scripts/csvjoin` now renames duplicate columns with integer suffixes to prevent collisions in output.
  * :doc:`/scripts/csvsql` now generates ``DateTime`` columns instead of ``Time`` columns.
  * :doc:`/scripts/csvsql` now generates ``Decimal`` columns instead of ``Integer``, ``BigInteger``, and ``Float`` columns.
  * :doc:`/scripts/csvsql` no longer generates max-length constraints for text columns.
  * The ``--doublequote`` long flag is gone, and the ``-b`` short flag is now an alias for ``--no-doublequote``.
  * When using the ``--columns`` or ``--not-columns`` options, you must not have spaces around the comma-separated values, unless the column names contain spaces.
  * When sorting, null values are now greater than other values instead of less than.
  * ``CSVKitReader``, ``CSVKitWriter``, ``CSVKitDictReader``, and ``CSVKitDictWriter`` have been removed. Use ``agate.csv.reader``, ``agate.csv.writer``, ``agate.csv.DictReader`` and ``agate.csv.DictWriter``.
  * Dropped support for older versions of PyPy.
  * Dropped Python 2.6 support.
  * If ``--no-header-row`` is set, the output will have column names ``a``, ``b``, ``c``, etc. instead of ``column1``, ``column2``, ``column3``, etc.
  * csvlook renders a simpler, markdown-compatible table.
  + Improvements:
  * csvkit is now tested against Python 3.6. (#702)
  * ``import csvkit as csv`` will now defer to agate readers/writers.
  * :doc:`/scripts/csvgrep` supports ``--no-header-row``.
  * :doc:`/scripts/csvjoin` supports ``--no-header-row``.
  * :doc:`/scripts/csvjson` streams input and output if the ``--stream`` and ``--no-inference`` flags are set.
  * :doc:`/scripts/csvjson` supports ``--snifflimit`` and ``--no-inference``.
  * :doc:`/scripts/csvlook` adds ``--max-rows``, ``--max-columns`` and ``--max-column-width`` options.
  * :doc:`/scripts/csvlook` supports ``--snifflimit`` and ``--no-inference``.
  * :doc:`/scripts/csvpy` supports ``--agate`` to read a CSV file into an agate table.
  * ``csvsql`` supports custom `SQLAlchemy dialects <http://docs.sqlalchemy.org/en/latest/dialects/>`_.
  * :doc:`/scripts/csvstat` supports ``--names``.
  * :doc:`/scripts/in2csv` CSV-to-CSV conversion streams input and output if the ``--no-inference`` flag is set.
  * :doc:`/scripts/in2csv` CSV-to-CSV conversion uses ``agate.Table``.
  * :doc:`/scripts/in2csv` GeoJSON conversion adds columns for geometry type, longitude and latitude.
  * Documentation: Update tool usage, remove shell prompts, document connection string, correct typos.
  + Fixes:
  * Fixed numerous instances of open files not being closed before utilities exit.
  * Change ``-b``, ``--doublequote`` to ``--no-doublequote``, as doublequote is True by default.
  * :doc:`/scripts/in2csv` DBF conversion works with Python 3.
  * :doc:`/scripts/in2csv` correctly guesses format when file has an uppercase extension.
  * :doc:`/scripts/in2csv` correctly interprets ``--no-inference``.
  * :doc:`/scripts/in2csv` again supports nested JSON objects (fixes regression).
  * :doc:`/scripts/in2csv` with ``--format geojson`` will print a JSON object instead of ``OrderedDict([(...)])``.
  * :doc:`/scripts/csvclean` with standard input works on Windows.
  * :doc:`/scripts/csvgrep` returns the input file's line numbers if the ``--linenumbers`` flag is set.
  * :doc:`/scripts/csvgrep` can match multiline values.
  * :doc:`/scripts/csvgrep` correctly operates on ragged rows.
  * :doc:`/scripts/csvsql` correctly escapes ``%%``` characters in SQL queries.
  * :doc:`/scripts/csvsql` adds standard input only if explicitly requested.
  * :doc:`/scripts/csvstack` supports stacking a single file.
  * :doc:`/scripts/csvstat` always reports frequencies.
  * The ``any_match`` argument of ``FilteringCSVReader`` now works correctly.
  * All tools handle empty files without error.
* Sun Jul 30 2017 bruno@ioda-net.ch
- Packaging : move to python singlespec
  + application are only py3 (no more alternatives)
  + fix copyright year
  + disable require on sphinx we don't have doc in pypi tar
  + use files.pythonhosted.org
  + remove shebang
  + adjust too strict version with sed in setup.py
- This update prepare the changes in version >1 with agathe
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Thu Dec 10 2015 bruno@ioda-net.ch
- Update to version 0.9.1:
  + Typo correction.
  + updated Kansas example data URL
  + Fix csvsort -c help text. Closes #373.
  + Add Dave Stanton to AUTHORS.
  + Fix typo. Closes #378.
  + Fix openpyxl version to work around bug. Closes #391.
    Rev down to 0.9.1 for imminent release.
  + Rev to 0.9.2 for dev.
  + in2csv: Support uppercase file extensions when guessing format.
- Packaging:
  + spec-cleaner
  + packaging with update-alternatives support for python3
    package
  + Added python-dbf and python-et_xmlfile as dependences
  + Add BuildRoot for fixing SLE_11 builds
* Sun Mar  8 2015 benoit.monin@gmx.fr
- update to version 0.9.0:
  * Write missing sections of the tutorial. (#32)
  * Remove -q arg from sql2csv (conflicts with common flag).
  * Fix csvjoin in case where left dataset rows without all columns.
  * Rewrote tutorial based on LESO data. (#324)
  * Don't error in csvjson if lat/lon columns are null. (#326)
  * Maintain field order in output of csvjson.
  * Add unit test for json in2csv. (#77)
  * Maintain key order when converting JSON into CSV. (#325.)
  * Upgrade python-dateutil to version 2.2 (#304)
  * Fix sorting of columns with null values. (#302)
  * Added release documentation.
  * Fill out short rows with null values. (#313)
  * Fix unicode output for csvlook and csvstat. (#315)
  * Add documentation for --zero. (#323)
  * Fix Integrity error when inserting zero rows in database with
    csvsql. (#299)
  * Add --count option to CSVStat.
  * Implement csvformat.
  * Fix bug causing CSVKitDictWriter to output 'utf-8' for blank
    fields.
- additional changes from 0.8.0:
  * Fix column specification in csvstat. (#236)
  * Added "Tips and Tricks" documentation. (#297, #298)
  * Remove unnecessary enumerate calls. (#292)
  * Deprecated DBF support for Python 3+.
  * Add support for Python 3.3 and 3.4 (#239)
- additional changes from 0.7.3
  * Fix date handling with openpyxl > 2.0 (#285)
  * Support SQL queries "directly" on CSV files. (#276)
  * Fix off-by-one error in open ended column ranges. (#238)
  * Add line numbers flag to csvlook (#244)
  * Only install argparse for Python < 2.7. (#224)
  * Fix DBF dependency. (#270)
- additional changes from 0.7.2
  * Fix CHANGELOG for release.
- additional changes from 0.7.1
  * Fix homepage url in setup.py.
- additional changes from 0.7.0
  * Fix XLSX datetime normalization bug. (#223)
  * Merged sql2csv utility (#259).
  * Validate csvsql DB connections before parsing CSVs. (#257)
  * Clarify install process for Ubuntu. (#249)
  * Clarify docs for --escapechar. (#242)
  * Make ``import csvkit`` API compatible with ``import csv``.
  * Update Travis CI link. (#258)
  * Use case-sensitive name for SQLAlchemy (#237)
- update URL
- add python-six as dependency
- rework the removal of shebangs to make it more generic
- add sql2csv to the package file
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 0.6.1
  + No changelog available
* Wed Jul 31 2013 hpj@urpla.net
- Update to version 0.5.0
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.3.0
* Wed Aug 31 2011 saschpe@suse.de
- Update to version 0.2.5:
  * Use proper tarball
- Regenerated with py2pack:
  * Proper version checks around fdupes
  * Simpler Buildrequires
  * Fixed several rpmlint issues (non-excutable scripts, summary)
* Mon Aug 22 2011 hpj@urpla.net
- initial package version 0.2.4 git 3f0d6c2
